pub enum Message {
Task(Box<dyn FnOnce() + Send>),
Window(WindowId, WindowMessage),
Webview(WindowId, WebviewMessage),
CreateWebview(Box<dyn FnOnce(&EventLoopWindowTarget<Message>, &Mutex<HashMap<Option<PathBuf>, WebContext>>) -> Result<WindowWrapper> + Send>, Sender<WindowId>),
CreateWindow(Box<dyn FnOnce() -> (String, WryWindowBuilder) + Send>, Sender<Result<Arc<Window>>>),
GlobalShortcut(GlobalShortcutMessage),
Clipboard(ClipboardMessage),
}
Tuple Fields of CreateWebview
Tuple Fields of CreateWindow
Tuple Fields of GlobalShortcut
Tuple Fields of Clipboard
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.